﻿using System;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Windows.Controls;
using System.Windows.Media;

namespace CalendarSelectors
{
	public partial class MainPage : UserControl
	{
		private EventsCollection eColl;
		public MainPage()
		{
			InitializeComponent();

			eColl = this.Resources["EventsList"] as EventsCollection;
		}

		private void AddNewDateClick(object sender, System.Windows.RoutedEventArgs e)
		{
			this.CalendarRefresh();
		}

		private void CalendarRefresh()
		{
			eColl.Add(new Event { Date = DateTime.Today });
			eColl.Add(new Event { Date = DateTime.Today.AddDays(1) });
			eColl.Add(new Event { Date = DateTime.Today.AddDays(2) });

			var styleSelector = radCalendar.DayButtonStyleSelector;
			radCalendar.DayButtonStyleSelector = null;
			radCalendar.DayButtonStyleSelector = styleSelector;
		}
	}

	public class EventsCollection : ObservableCollection<Event> { }

	public class Event : INotifyPropertyChanged
	{
		public Event()
		{
			_date = DateTime.Now;
		}

		public int Day
		{
			get
			{
				return this.Date.Day;
			}
			set
			{
				DateTime today = DateTime.Now;
				this.Date = new DateTime(today.Year, today.Month, value);
			}
		}

		private DateTime _date;
		public DateTime Date
		{
			get
			{
				return this._date;
			}
			set
			{
				if (this._date != value)
				{
					this._date = value;
					this.FormatedDate = value.ToString("dddd, MMMM dd");
					this.OnPropertyChanged("Date");
					this.OnPropertyChanged("Day");
				}
			}
		}

		private string _formatedDate;
		public string FormatedDate
		{
			get
			{
				return this._formatedDate;
			}
			protected set
			{
				if (this._formatedDate != value)
				{
					this._formatedDate = value;
					this.OnPropertyChanged("FormatedDate");
				}
			}
		}

		private string _title;
		public string Title
		{
			get
			{
				return this._title;
			}
			set
			{
				if (this._title != value)
				{
					this._title = value;
					this.OnPropertyChanged("Title");
				}
			}
		}

		private string _company;
		public string Company
		{
			get
			{
				return this._company;
			}
			set
			{
				if (this._company != value)
				{
					this._company = value;
					this.OnPropertyChanged("Company");
				}
			}
		}

		private string _description;
		public string Description
		{
			get
			{
				return this._description;
			}
			set
			{
				if (this._description != value)
				{
					this._description = value;
					this.OnPropertyChanged("Description");
				}
			}
		}

		private Brush _brush;
		public Brush Brush
		{
			get
			{
				return this._brush;
			}
			set
			{
				this._brush = value;
				this.OnPropertyChanged("Brush");
			}
		}

		protected void OnPropertyChanged(string propertyName)
		{
			if (this.PropertyChanged != null)
			{
				PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
			}
		}
		public event PropertyChangedEventHandler PropertyChanged;
	}
}
